/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.cdc.common.udf;

import org.apache.flink.cdc.common.annotation.PublicEvolving;
import org.apache.flink.cdc.common.types.DataType;

/**
 * Base interface for creating a UDF in transform projection and filtering expressions. You should
 * define at least one {@code eval} method.
 */
@PublicEvolving
public interface UserDefinedFunction {
    default DataType getReturnType() {
        return null;
    }

    /**
     * This will be invoked every time when a UDF got created.
     *
     * <p>this method is {@link Deprecated}, please use {@link #open(UserDefinedFunctionContext)}
     * instead.
     */
    @Deprecated
    default void open() throws Exception {}

    /** This will be invoked every time when a UDF got created. */
    default void open(UserDefinedFunctionContext context) throws Exception {
        open();
    }

    /** This will be invoked before a UDF got destroyed. */
    default void close() throws Exception {}
}
